==> invest_guard-0.1.14.tar.gz: invest_guard-0.1.14/README.md <==
# Invest Guard

Invest Guard is a command-line interface (CLI) tool for fetching and analyzing financial data from various sources. With Invest Guard, you can easily retrieve stock prices, company information, historical data, and more, all from the comfort of your terminal.

## Features

- **Data Fetching**: Fetch real-time and historical data for stocks and other financial instruments.
- **Command-Line Interface**: Intuitive command-line interface for easy interaction and data retrieval.
- **Multiple Data Sources**: Support for fetching data from various sources, including Yahoo Finance and others.
- **Customization**: Flexible command-line options to customize data retrieval, such as specifying ticker symbols, date ranges, and more.
- **User-Friendly**: Simple and straightforward interface with clear prompts and feedback messages.
- **Modular Design**: Modular architecture with separate modules for different functionalities, making it easy to extend and maintain.

## Installation

You can install Invest Guard using pip:

```bash
pip install invest-guard
```

## Usage

To fetch stock data, simply use the `guard fetch` command followed by the appropriate options. For example:

```bash
guard fetch --ticker AAPL --start-date 2022-01-01 --end-date 2022-12-31
```

For more information on available commands and options, refer to the [documentation](https://github.com/Work-With-Phoenix/invest-guard).

## Contributing

Contributions are welcome! If you encounter any issues or have suggestions for improvements, please feel free to open an issue or submit a pull request on [GitHub](https://github.com/Work-With-Phoenix/invest-guard).

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

==> invest_guard-0.2.0.tar.gz: invest_guard-0.2.0/README.md <==
# Invest Guard

Invest Guard is a command-line interface (CLI) tool for fetching and analyzing financial data from various sources. With Invest Guard, you can easily retrieve stock prices, company information, historical data, and more, all from the comfort of your terminal.

## Features

- **Data Fetching**: Fetch real-time and historical data for stocks and other financial instruments.
- **Command-Line Interface**: Intuitive command-line interface for easy interaction and data retrieval.
- **Multiple Data Sources**: Support for fetching data from various sources, including Yahoo Finance and others.
- **Customization**: Flexible command-line options to customize data retrieval, such as specifying ticker symbols, date ranges, and more.
- **User-Friendly**: Simple and straightforward interface with clear prompts and feedback messages.
- **Modular Design**: Modular architecture with separate modules for different functionalities, making it easy to extend and maintain.

## Installation

You can install Invest Guard using pip:

```bash
pip install invest-guard
```

## Usage

To fetch stock data, simply use the `guard fetch` command followed by the appropriate options. For example:

```bash
guard fetch --asset-type stock --ticker AAPL -s yahoo -z "United States" --start-date 2022-01-01 --end-date 2022-12-31
```

For more information on available commands and options, refer to the [documentation](https://phoenixui.cloud/projects/invest-guard).

## Contributing

Contributions are welcome! If you encounter any issues or have suggestions for improvements, please feel free to open an issue or submit a pull request on [GitHub](https://github.com/Work-With-Phoenix/invest-guard).

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
